@@ -436,7 +436,7 @@ class AzureBatch(BackendBase):
         # BATCH BUG WORKAROUND: tried to create a resource file for FOLDER instead of enumerating all blobs
         # but always get "blob not found" error (before, before/, before/** - no form works)
         #blob_names = [before_blob_path + "/**"]
-        blob_names = store_provider.list_blobs(jobs_container, before_blob_path)
+        blob_names = store_provider.list_blobs(jobs_container, before_blob_path, recursive=True)
 
         if not fake_submit:
             assert len(blob_names) > 0
@@ -1571,3 +1571,54 @@ class AzureBatch(BackendBase):
         # this is done by the batch service at the end of our batch task
         pass            
 
+    def get_ssh_creds(self, config, job_id, node_index, workspace_id):
+        import azure.batch as batch
+        import azure.batch.batch_auth as batch_auth
+
+        # get batch credentials
+        service_name = "xtsandboxbatch"
+        batch_creds = config.get_service(service_name)
+        batch_name = service_name
+        batch_key = batch_creds["key"]
+        batch_url = batch_creds["url"]
+
+        credentials = batch_auth.SharedKeyCredentials(batch_name, batch_key)
+        batch_client = batch.BatchServiceClient(credentials, batch_url= batch_url)
+        compute_node_ops = batch_client.compute_node
+
+        # get compute node
+        store_id = config.get("store")
+        batch_job_id = "{}__{}__{}".format(store_id, workspace_id, job_id)
+
+        node_index = 0
+        task_id = "task" + str(node_index)
+        task = batch_client.task.get(batch_job_id, task_id)
+
+        node_info = task.node_info
+        if not node_info:
+            errors.user_error("node information for job is not available (job is not yet or no longer active)")
+            
+        pool_id = node_info.pool_id
+        node_id = node_info.node_id
+
+        node = batch_client.compute_node.get(pool_id, node_id)
+        #ip_address = node.ip_address
+
+        result = compute_node_ops.get_remote_login_settings(pool_id, node_id)
+        ip_addr = result.remote_login_ip_address
+        port = result.remote_login_port
+
+        # create the xt-user for this node
+        user_name = "xt-user"
+        pw = "kt#abc!@XTwasHere"
+        is_admin = True
+        user = compute_node_ops.models.ComputeNodeUser(name=user_name, password=pw, is_admin=is_admin)
+
+        try:
+            compute_node_ops.add_user(pool_id, node_id, user)
+        except:
+            # ignore if user already exists
+            pass
+
+        return {"user": user_name, "pw": pw, "ip_addr": ip_addr, "port": port}
+
