@@ -623,6 +623,7 @@ class XTController(rpyc.Service):
                             run_info.started = time.time()
 
         if run_info:
+            # got a run from the queue that is ready to run (or spawn a child)
             self.process_queue_entry(run_info)
             processed_entry = True
 
@@ -653,18 +654,18 @@ class XTController(rpyc.Service):
                     self.first_run_index = 1
                     run_index = self.next_run_list_index
                     self.next_run_list_index += 1
+                    entry = {"status": "unstarted", "run_index": run_index}
 
                 else:
                     # let database allocate next job-level run_index
                     run_index =  self.store.database.get_next_run_index(context.ws, context.job_id)
+                    entry = {"status": "unstarted", "run_index": run_index}
 
                     if self.total_run_count and run_index >= self.total_run_count:
                         # all runs completed; tell controller to exit
-                        self.stop_processing_runs = True
-                        return
-
-                entry = {"status": "unstarted", "run_index": run_index}
-
+                        log_info("all runs completed for parent", run_info.run_name)
+                        entry = None
+ 
             elif self.next_run_list_index < len(self.run_indexes):
                 run_index = self.run_indexes[self.next_run_list_index]
                 self.next_run_list_index += 1
