@@ -953,7 +953,7 @@ class ImplCompute(ImplBase):
     @option("resume-name", help="when resuming a run, this names the previous run")
     @option("runs", default=None, type=int, help="the total number of runs across all nodes (for hyperparameter searches)")
     @option("runs-per-set", default="$hyperparameter-search.runs-per-set", type=int, help="how many runs to do for each CCD hp set explored")
-    @option("schedule", default="static", values=["static", "dynamic"], help="specifies if runs are pre-assigned to each node or allocate on demand")
+    @option("schedule", default="$general.schedule", values=["static", "dynamic"], help="specifies if runs are pre-assigned to each node or allocate on demand")
     @option("search-type", values=["random", "grid", "bayesian", "dgd", "ccd"], default="$hyperparameter-search.search-type", help="the type of hyperparameter search to perform")
     @option("seed", default=None, help="the random number seed that can be used for reproducible HP searches")
     @option("service", type=str, default=DEFAULT_FROM_COMPUTE, help="the name of the xt config-specified compute service to use for this job")
