@@ -33,13 +33,13 @@ To add a new job info column (defined at job submit time):
 
 '''
 
-# NEW COLS: sla, low_pri, vm_size, sku, service_name, service_type, aml_compute, compute_target, num_dgd_seeds
+# NEW COLS: sla, low_pri, vm_size, sku, service_name, service_type, aml_compute, compute_target, num_dgd_seeds, schedule
 # LEGACY column for old jobs: "compute" (logged as "target")
 
 job_info_props = {"_id": 1, "aml_compute": 1, "compute": 1, "compute_target": 1,"concurrent": 1, "exper_name": 1, "hold": 1, "job_id": 1, "job_num": 1,
     "job_guid": 1, "job_secret": 1, "low_pri": 1, "node_count": 1, "num_dgd_seeds": 1, "primary_metric": 1, "run_count": 1, "repeat": 1, 
     "schedule": 1, "search_type": 1, "search_style": 1, "service_name": 1, "service_type": 1, "username": 1, "xt_cmd": 1, "started": 1,
-    "pool_info": 1, "service_job_info": 1, "sku": 1, "sla": 1, "ws_name": 1, "sleep_on_exit": 1, "vm_size": 1}
+    "pool_info": 1, "service_job_info": 1, "sku": 1, "sla": 1, "schedule": 1, "sleep_on_exit": 1, "vm_size": 1, "ws_name": 1}
 
 job_stats_props = {"job_status": 1, "completed_runs": 1, "error_runs": 1, "running_runs": 1, 
     "running_nodes": 1, "total_runs": 1, "db_retries": 1, "storage_retries": 1,
@@ -184,15 +184,14 @@ def build_job_filter_dict(ws_name, job_list, user_to_actual, builder, workspace,
 
 user_to_actual = {"aml_compute": "aml_compute", "cluster": "cluster", "compute_target": "compute_target", 
     "docker": "environment", "experiment": "exper_name",
-    "hold": "hold", "job": "job_id","job_num": "job_num", "low_pri": "low_pri", "num_dgd_seeds": "num_dgd_seeds",
+    "hold": "hold", "hparams": "hparams", "job": "job_id","job_num": "job_num", "low_pri": "low_pri", "num_dgd_seeds": "num_dgd_seeds",
     "node_count": "node_count", "primary_metric": "primary_metric", "queue": "queue", 
-    "repeat": "repeat", "search": "search_type", "service_name": "service_name", "service_type": "service_type", 
-    "sku": "sku", "runs": "run_count", "search_style": "search_style", "sla": "sla", 
-    "started": "started", "username": "username", "target": "compute",
+    "repeat": "repeat", "schedule": "schedule", "search": "search_type", "service_name": "service_name", 
+    "service_type": "service_type", "sku": "sku", "sleep_on_exit": "sleep_on_exit", 
+    "runs": "run_count", "search_style": "search_style", "sla": "sla", 
+    "started": "started", "tags": "tags", "target": "compute", "username": "username", 
     "vc": "vc", "vm_size": "vm_size", "workspace": "ws_name",  
-    "hparams": "hparams", "tags": "tags", "sleep_on_exit": "sleep_on_exit", 
-
-
+     
     # dynamic properties (get updated at various stages of job)
     "status": "job_status", "running_nodes": "running_nodes", 
     "running_runs": "running_runs", "error_runs": "error_runs", "completed_runs": "completed_runs",
@@ -217,6 +216,7 @@ std_cols_desc = {
     "queue": "the Philly queue that the job was submitted to",
     "repeat": "the repeat count specified for the job",
     "runs": "the total number of runs for the job",
+    "schedule": "how runs are assigned to nodes (static or dynamic)",
     "search": "the type of hyperparameter search requested",
     "search_style": "describes how search is being accomplished (one of: static, dynamic, multi, repeat, single)",
     "service_name": "the name of the service specified in the target for this job",
