@@ -15,7 +15,6 @@ from xtlib import errors
 from xtlib import console
 from xtlib import constants
 from xtlib import run_helper
-from xtlib import job_helper
 from xtlib import store_utils
 from xtlib.hp_set import HpSetFormatter
 from xtlib.report_builder import ReportBuilder   
@@ -786,6 +785,9 @@ class PlotBuilder():
                     self.break_filter_name = break_name
 
                     break_values = self.get_unique_values(break_name)
+                    if not break_values:
+                        errors.general_error("break value not found (or has no data): {}".format(break_name))
+                        
                     actual_col = {"name": break_name, "break": True, "data": break_values}
                     loops.append(actual_col)
 
@@ -809,6 +811,9 @@ class PlotBuilder():
             new_series = []
             line_index = 0
 
+            if not values:
+                errors.internal_error("no values found for: {}".format(name))
+
             for value in values:
                 if series:
                     # not the first series: copy existing series and add our name/value to each entry
@@ -856,7 +861,6 @@ class PlotBuilder():
         import seaborn as sns
         import matplotlib.pyplot as plt
         import matplotlib as mpl
-        import pylab
 
         if not self.show_toolbar:
             # hide the ugly toolbar at bottom left of plot window
@@ -912,16 +916,20 @@ class PlotBuilder():
         fig.suptitle(title, fontsize=16)
 
         if self.timeout:
+            #console.print("starting bg thread for timer")
+
             # build a thread to close our plot window after specified time
             from threading import Thread
 
             def set_timer(timeout):
-                console.print("set_timer called: timeout=", self.timeout)
-                time.sleep(self.timeout)
-                console.diag("timer triggered!")
+                console.print("set_timer called: timeout=", timeout)
+                time.sleep(timeout)
+                #console.print("timer triggered!")
 
-                plt.close("all")
-                print("closed all plots and the fig")
+                # plt.close() just hangs as of May-22-2022
+                # plt.close("all")
+                from PyQt5.QtWidgets import QApplication
+                QApplication.quit()
 
             thread = Thread(target=set_timer, args=[self.timeout])
             thread.daemon = True    # mark as background thread
@@ -952,9 +960,9 @@ class PlotBuilder():
         #     records = [{"hp_set": self.hp_sets_by_name[hp_set_name]} for hp_set_name in self.hp_sets_names_plotted]
         #     self.hp_set_report(records)
 
-        self.finish_plot(plt, fig, plots, pylab)
+        self.finish_plot(plt, fig, plots)
 
-    def finish_plot(self, plt, fig, plots, pylab):
+    def finish_plot(self, plt, fig, plots):
 
         if self.save_to:
             plt.savefig(self.save_to)
@@ -1018,7 +1026,7 @@ class PlotBuilder():
                     x, y = self.margins.split(",")
                     ax.margins(float(x), float(y))
                 else:
-                    ax.margins(float(self.margins))
+                    ax.margins(float(self.margins), tight=False)
 
         if self.y_ticks:
             ax.set_yticks(self.y_ticks)
@@ -1026,7 +1034,7 @@ class PlotBuilder():
         self.enable_legend_picking(fig, plots)
 
         if self.show_plot:
-            pylab.show()
+            plt.show()
             #fig.canvas.draw()
 
     def enable_legend_picking(self, fig, plots):
@@ -1446,7 +1454,7 @@ class PlotBuilder():
                 text = text.replace("$experiment", exper_name)
             
             if "$group" in text:
-                text = text.replace("$group", group_name if group_name else "")
+                text = text.replace("$group", str(group_name) if group_name is not None else "")
 
             if "$col" in text:
                 text = text.replace("$col", col)
