@@ -68,7 +68,7 @@ def get_controller_wrapped_counts():
             process_name = p.name().lower()
             #log_print("process_name=", process_name)
 
-            if process_name in ["python", "bash", "python.exe", "cmd.exe"]:
+            if process_name in ["python", "python3", "bash", "python.exe", "cmd.exe"]:
                 #log_print("process name: {}".format(p.name()))
                 cmd_line = " ".join(p.cmdline())
                 #log_print("  cmd_line: " + cmd_line)
