@@ -760,6 +760,15 @@ class Runner():
         if dry_run:
             return
 
+        if not using_hp and not using_aml_hparam:
+            # zap values of related arguments for better run reports (omitting empty columns)
+            search_type = None
+            search_style = None
+            static_search = None
+
+            args["search_type"] = search_type
+            args["static_search"] = static_search
+
         # make new values available
         args["search_style"] = search_style
         args["total_run_count"] = total_run_count
