@@ -232,7 +232,7 @@ class StoreBlobObjs():
 
         if "**" in wc_target:
             # case 3: return all blobs for target and child directories
-            names = list(self.provider.list_blobs(container, path=path))
+            names = list(self.provider.list_blobs(container, path=path, recursive=True))
         elif wc_target and ("*" in wc_target or "?" in wc_target):
             # case 2: normal wildcards specified (for target directory only)
             # use delimiter-trick to limit listing to target directory only
@@ -380,12 +380,12 @@ class StoreBlobObjs():
             container, path, wc_target, subdirs))
 
         # special case: if container/path exists as a blob, treat as if wildcard on parent
-        if not wc_target and container and self.provider.does_blob_exist(container, path):
+        if not wc_target and container and path and self.provider.does_blob_exist(container, path):
             wc_target = os.path.basename(path)
             path = os.path.dirname(path)
 
         service_name = self.provider.get_service_name()
-        dd = {"store_name": "XT Store ({})".format(service_name)}
+        store_name =  "XT Store ({})".format(service_name)
         #console.print("dd=", dd)
 
         if not container:
@@ -401,7 +401,7 @@ class StoreBlobObjs():
                 for ws_name in folder_names:
                     # get blobs from AZURE
                     console.diag("reading blobs for ws={}".format(ws_name))
-                    blobs  = self.provider.list_blobs(ws_name, path=None, return_names=False)
+                    blobs  = self.provider.list_blobs(ws_name, path=None, return_names=False, recursive=True)
                     blobs = list(blobs)
 
                     ws_folders = self._build_folders_from_blobs(blobs, ws_name, 
@@ -411,25 +411,24 @@ class StoreBlobObjs():
         else:
             # get blobs from AZURE
             actual_path = path if path else None
-            blobs  = self.provider.list_blobs(container, path=actual_path, return_names=False)
+
+            blobs  = self.provider.list_blobs(container, path=actual_path, return_names=False, recursive=False)
             blobs = list(blobs)
 
+            def wildcard_match(blob, wc_target):
+                bname = blob.name[:-1] if blob.name.endswith("/") else blob.name
+                matches = fnmatch(os.path.basename(bname), wc_target)
+                return matches
+
             if wc_target:
-                # apply filter
-                blobs = [blob for blob in blobs if fnmatch(os.path.basename(blob.name), wc_target)]
+                # apply wildcard as filter
+                blobs = [blob for blob in blobs if wildcard_match(blob, wc_target)]
 
             console.diag("list_blobs returned: len(blobs)={}".format(len(blobs)))
 
-            folders = self._build_folders_from_blobs(blobs, container, path, subdirs)
+            folder = self._build_folder_from_blobs(blobs, container, path, subdirs)
         
-        # filter folders as per subdirs
-        if not subdirs is True:
-            # subdirs is set to an int value
-            #console.print("filtering by subdirs=", subdirs)
-            folders = [f for f in folders if f["level"] <= subdirs]
- 
-        dd["folders"] = folders
-        return dd
+        return folder, store_name
 
     def _get_first_dir(self, path):
         first_dir = None
@@ -451,100 +450,78 @@ class StoreBlobObjs():
 
         return first_dir, rest
 
-    def _build_folders_from_blobs(self, blobs, ws_name, base_path, subdirs):
-        folders_by_name = {}
-        folders = []    # ordered list of folders
+    def _build_folder_from_blobs(self, blobs, container_name, base_path, subdirs, current_folder=None, level=0):
+        next_level = 1 + level
 
-        base_len = len(base_path)
-        if base_path.endswith("*"):
-            base_len -= 1
-        if base_path:
-            base_len += 1    # for trailing slash
-            
-        base_folder = self._get_folder(folders, folders_by_name, ws_name, base_path, base_len)
-        #console.print("base_folder=", base_folder)
+        if current_folder is None:
+            current_folder = self._make_folder(container_name, folder_path=base_path, level=level)
 
+        # process PREFIX or BLOB entries
         for i, blob in enumerate(blobs):
-
             full_blob_path = blob.name
             #console.print("full_blob_path=", full_blob_path)
 
             file_path = os.path.dirname(full_blob_path)
             parent_path = os.path.dirname(file_path)
+            is_prefix = not hasattr(blob, "properties")
 
-            if subdirs or file_path == base_path:
-                # add file to its folder
-                folder = self._get_folder(folders, folders_by_name, ws_name, file_path, base_len)
-                
+            if is_prefix:
+                # its a folder name
+                # create an empty folder entry
+                empty_folder = self._make_folder(container_name=container_name, folder_path=full_blob_path, level=next_level)
+                current_folder["dirs"].append(empty_folder)
+            else:
                 # create a new file entry
                 fi = {"name": os.path.basename(blob.name)}
-                fi["size"] = blob.properties.content_length 
-                fi["modified"] = blob.properties.last_modified.timestamp()
-                folder["files"].append(fi)
 
-            if subdirs:
-                # add all path parts to their parent folders
-                child_path = file_path
+                if self.provider_name.endswith("21"):
+                    fi["size"] = blob.properties.content_length
+                    fi["modified"] = blob.properties.last_modified.timestamp()
+                else:
+                    # version 12.12.0 format 
+                    fi["size"] = blob.size
+                    fi["modified"] = blob.properties.last_modified.timestamp()
 
-                while len(parent_path) >= len(base_path):    # and parent_path != "/":
-                    #console.print("  parent_path=", parent_path, ", child_path=", child_path, ", base_path=", base_path)
-                    if parent_path:
-                        parent_folder = self._get_folder(folders, folders_by_name, ws_name, parent_path, base_len)
-                    else:
-                        parent_folder = base_folder
+                current_folder["files"].append(fi)
 
-                    # add child dir, if needed
-                    child_name = os.path.basename(child_path)
-                    dirs = parent_folder["dirs"]
-                    if not child_name in dirs:
-                        dirs.append(child_name)
+        # after processing all contents of current folder
+        current_folder["processed"] = True
 
-                    # stop when base_path folder has been added to
-                    if parent_path == base_path:
-                        break
+        if subdirs is True or subdirs >= next_level:
+            # build a folder for each dir we found in this folder
+            for subfolder in current_folder["dirs"]:
+                subfolder_name = base_path + subfolder["name"] + "/"   # add slash for "return contents of folder"
 
-                    # process next level up
-                    child_path = parent_path
-                    parent_path = os.path.dirname(parent_path)
-            else:
-                # just process the left-most directory part of rel_path
-                rel_file_path = file_path[base_len:]
-                left_most_path, rest = self._get_first_dir(rel_file_path)
-                #console.print("FIRST left_most_path=", left_most_path, ", rest=", rest)
-                if left_most_path:
-                    # add child dir, if needed
-                    dirs = base_folder["dirs"]
-                    child_name = os.path.basename(left_most_path)
-                    if not child_name in dirs:
-                        dirs.append(child_name)
-        
-        return folders
+                sub_blobs =  self.provider.list_blobs(container_name, path=subfolder_name, return_names=False, recursive=True)
+                self._build_folder_from_blobs(sub_blobs, container_name, subfolder_name, subdirs, current_folder=subfolder, level=next_level)
 
-    def _get_folder(self, folders, folders_by_name, ws_name, path, base_name_len):
-        if not path in folders_by_name:
-            # create a new folder
-            display_name = "/" + ws_name 
-            if path and path != "/":
-                display_name += "/" + path
-            rel_path = path[base_name_len:]
-            #console.print("rel_path=", rel_path)
+        return current_folder
 
-            folder = {"folder_name": display_name}
-            folder["dirs"] = []
-            folder["files"] = []
-            folder["level"] = 1 + rel_path.count("/") if rel_path else 0
-            folders_by_name[path] = folder
-            folders.append(folder)
+    def _make_folder(self, container_name, folder_path, level):
+        if folder_path.endswith("/"):
+            folder_path = folder_path[:-1]
+            
+        # create a new folder
+        display_name = "/" + container_name 
+        if folder_path and folder_path != "/":
+            display_name += "/" + folder_path
+        #rel_path = folder_path[base_name_len:]
+        #console.print("rel_path=", rel_path)
+
+        folder = {"name": os.path.basename(folder_path)}
+        folder["full_path"] = display_name
+        folder["dirs"] = []
+        folder["files"] = []
+        folder["level"] = level   # 1 + rel_path.count("/") if rel_path else 0
+        folder["processed"] = False
 
-            #console.print("folder added: name=", display_name, ", level=", folder["level"])
-        
-        folder = folders_by_name[path]
         return folder
 
     def _get_root_folders(self):
         folder_names = self.provider.list_containers()
 
-        folder = {"folder_name": "/"}
+        folder = {"name": "/"}
+        folder["full_path"] = "/"
         folder["level"] = 0
         folder["files"] = []
         folder["dirs"] = folder_names
@@ -566,8 +543,8 @@ class StoreBlobObjs():
 
         return old_count
         
-    def list_blobs(self, container, blob_path, return_names=True):
-        blobs  = self.provider.list_blobs(container, path=blob_path, return_names=return_names)
+    def list_blobs(self, container, blob_path, return_names=True, recursive=True):
+        blobs  = self.provider.list_blobs(container, path=blob_path, return_names=return_names, recursive=recursive)
         return blobs
 
     # ---- SHARES ----
@@ -746,7 +723,7 @@ class StoreBlobObjs():
         # so, we need to enumerate and delete each one
         
         # since we are deleting from the list we are enumerating, safest to grab the whole list up frong
-        blobs = list(self.provider.list_blobs(ws_name, path=self._run_path(run_name) + "/"))
+        blobs = list(self.provider.list_blobs(ws_name, path=self._run_path(run_name) + "/", recursive=True))
         for blob in blobs:
             self.provider.delete_blob(ws_name, blob)   
 
@@ -756,7 +733,7 @@ class StoreBlobObjs():
 
         # copy a single blob at a time
         #for source_blob_path in self.bs.list_blob_names(source_workspace_name, source_run_name):
-        for source_blob in self.provider.list_blobs(source_workspace_name, path=self._run_path(source_run_name)  + "/"):
+        for source_blob in self.provider.list_blobs(source_workspace_name, path=self._run_path(source_run_name)  + "/", recursive=False):
             dest_blob_path = self._run_path(dest_run_name)  + "/" + self._remove_first_node(source_blob)
 
             # copy single blob within same storage service
@@ -1132,7 +1109,7 @@ class BlobsObject():
         container, path, wc_target = self._get_container_path_target(wildcard)
         names = self.store._list_wild_blobs(container, path, wc_target, include_folder_names=True)
 
-        if not full_paths and path != "/":
+        if not full_paths and path and path != "/":
             # convert to relative paths (relative to the path for this job/run/experiment/workspace)
             path_len = 1 + len(path)
             #console.print("PRE names=", names)
