@@ -837,7 +837,7 @@ def expand_xt_vars(text, job_runs=None, run_id=None, job_id=None, node_index=0,
             text = text.replace("$username", username)
 
         if "$job_id" in text:
-            job_id = args["job_id"]
+            job_id = args["job_id"] if args else job_id
             text = text.replace("$job_id", job_id)
 
         if "$run_id" in text:
